@@ -8,13 +8,14 @@ logger = logging.getLogger(__name__)
 
 # https://daskhub.dev.ctaodc.ch/services/downloadservice/fetch/pnfs/cta.cscs.ch/lst/DL1/20230226/v0.9_calib12100/tailcut84
 
+hubbase = "http://hub:5000/services/downloadservice/fetch/"
 
 def list_dir(url):
-    return requests.get(
-            urljoin("http://hub:5000/services/downloadservice/fetch/pnfs/cta.cscs.ch/", url),
+    return [u.replace(hubbase, "") for u in requests.get(
+            urljoin(hubbase, "pnfs/cta.cscs.ch", url),
             params = {'token': os.getenv("JUPYTERHUB_API_TOKEN")},
             stream=True
-        ).json()
+        ).json()['urls']]
 
 
 def fetch_and_save_file(url, fn=None):
@@ -25,7 +26,7 @@ def fetch_and_save_file(url, fn=None):
 
     with open(fn, "wb") as outf:
         with requests.get(
-            urljoin("http://hub:5000/services/downloadservice/fetch/pnfs/cta.cscs.ch/", url),
+            urljoin(hubbase, "pnfs/cta.cscs.ch", url),
             params = {'token': os.getenv("JUPYTERHUB_API_TOKEN")},
             stream=True
         ) as f:          
